@@ -1,11 +1,12 @@
 from __future__ import annotations
 
 from abc import ABCMeta
-from enum import Enum, EnumMeta
-from typing import Any, Self
+from enum import Enum, EnumMeta, ReprEnum
+from enum import property as enum_property
+from typing import TYPE_CHECKING, Any, Self
 
-from ..exceptions import NotFoundEnumValueError
-from ..types import FuncExcept
+from ..exceptions import CustomTypeError, NotFoundEnumValueError
+from ..types import FuncExcept, copy_signature
 
 __all__ = ["CustomEnum", "CustomIntEnum", "CustomStrEnum", "EnumABCMeta"]
 
@@ -13,6 +14,25 @@ __all__ = ["CustomEnum", "CustomIntEnum", "CustomStrEnum", "EnumABCMeta"]
 class EnumABCMeta(EnumMeta, ABCMeta):
     """Metaclass combining EnumMeta and ABCMeta to support abstract enumerations."""
 
+    @copy_signature(EnumMeta.__new__)
+    def __new__(mcls, *args: Any, **kwargs: Any) -> Any:
+        enum_cls = super().__new__(mcls, *args, **kwargs)
+
+        if len(enum_cls) == 0:
+            return enum_cls
+
+        if enum_cls.__abstractmethods__:
+            raise CustomTypeError(
+                "Can't instantiate abstract class {cls_name} without an implementation "
+                "for abstract method{plural} {methods}.",
+                enum_cls,
+                cls_name=enum_cls.__name__,
+                plural="s" if len(enum_cls.__abstractmethods__) > 1 else "",
+                methods=", ".join(f"'{n}'" for n in sorted(enum_cls.__abstractmethods__)),
+            )
+
+        return enum_cls
+
 
 class CustomEnum(Enum):
     """Base class for custom enums."""
@@ -53,13 +73,21 @@ class CustomEnum(Enum):
         ) from None
 
 
-class CustomIntEnum(int, CustomEnum):
+class CustomIntEnum(int, CustomEnum, ReprEnum):
     """Base class for custom int enums."""
 
-    _value_: int
+    if TYPE_CHECKING:
+        _value_: int
+
+        @enum_property
+        def value(self) -> int: ...
 
 
-class CustomStrEnum(str, CustomEnum):
+class CustomStrEnum(str, CustomEnum, ReprEnum):
     """Base class for custom str enums."""
 
-    _value_: str
+    if TYPE_CHECKING:
+        _value_: str
+
+        @enum_property
+        def value(self) -> str: ...
